Module: Permalink

Defined in:
lib/nimbleshop/permalink/builder.rb

Overview

This module builds permalink when the record is created for the very first time.

Usage:

class Product < ActiveRecord::Base include BuildPermalink build_permalink allow_nil: true end

build_permalink line is needed only if you are passing parameter otherwise that line can be omitted

Defined Under Namespace

Modules: Builder